@@ -50,3 +50,18 @@ fn error_is_send() {
     fn is_send<T: Send>() {}
     is_send::<Error>();
 }
+
+
+/// Unknown error from `crates_parallel`
+#[derive(Debug)]
+pub struct CratesIterError;
+
+impl std::error::Error for CratesIterError {
+}
+
+impl fmt::Display for CratesIterError {
+    #[cold]
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.write_str("error while iterating git repository")
+    }
+}
